@@ -58,30 +58,6 @@ test_that("A basic freqlist call", {
   )
 })
 
-test_that("A basic freqlist call--subsetted", {
-  expect_identical(
-    capture.output(summary(freqlist(TAB.subset))),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
-      "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
-      "|High  |Female |I     |    4|       4|        5.19|       5.19|",
-      "|      |       |II    |    8|      12|       10.39|      15.58|",
-      "|      |       |III   |    3|      15|        3.90|      19.48|",
-      "|      |Male   |I     |    7|      22|        9.09|      28.57|",
-      "|      |       |II    |    2|      24|        2.60|      31.17|",
-      "|      |       |III   |    6|      30|        7.79|      38.96|",
-      "|Low   |Female |I     |    7|      37|        9.09|      48.05|",
-      "|      |       |II    |    8|      45|       10.39|      58.44|",
-      "|      |       |III   |    2|      47|        2.60|      61.04|",
-      "|Med   |Female |II    |   11|      58|       14.29|      75.32|",
-      "|      |       |III   |    3|      61|        3.90|      79.22|",
-      "|      |Male   |II    |    8|      69|       10.39|      89.61|",
-      "|      |       |III   |    8|      77|       10.39|     100.00|"
-    )
-  )
-})
-
 test_that("groupBy option in freqlist call", {
   expect_identical(
     capture.output(summary(freqlist(TAB, groupBy = "Group"), single = FALSE)),
@@ -115,7 +91,7 @@ test_that("groupBy option in freqlist call", {
       "|      |       |III   |    8|      30|       26.67|     100.00|"
     )
   )
-  
+
   expect_error(freqlist(TAB, groupBy = "group"))
 })
 
@@ -203,7 +179,21 @@ test_that("Changing the labels", {
       "|          |Heinzen     |   29|      90|       32.22|     100.00|"
     )
   )
-  
+
+  expect_identical(
+    capture.output(summary(freqlist(TAB.na, na.options = "include", labelTranslations = list("Treatment", "Ethan Rocks")))),
+    c(""                                                                 ,
+      ""                                                                 ,
+      "|Treatment |Ethan Rocks | Freq| cumFreq| freqPercent| cumPercent|",
+      "|:---------|:-----------|----:|-------:|-----------:|----------:|",
+      "|A         |Ethan       |   17|      17|       18.89|      18.89|",
+      "|          |Heinzen     |   16|      33|       17.78|      36.67|",
+      "|          |NA          |    3|      36|        3.33|      40.00|",
+      "|B         |Ethan       |   25|      61|       27.78|      67.78|",
+      "|          |Heinzen     |   29|      90|       32.22|     100.00|"
+    )
+  )
+
   expect_identical(
     capture.output(summary(freqlist(TAB.na, na.options = "include", labelTranslations = c("Treatment", "Ethan Rocks")))),
     c(""                                                                 ,
@@ -217,11 +207,11 @@ test_that("Changing the labels", {
       "|          |Heinzen     |   29|      90|       32.22|     100.00|"
     )
   )
-  
+
   expect_error(freqlist(TAB.na, labelTranslations = c("Treatment", "Ethan Rocks", "Oops!")))
-  
+
   tmp <- freqlist(TAB.na, na.options = "include")
-  labels(tmp) <- c("Treatment", "Ethan Rocks")  
+  labels(tmp) <- c("Treatment", "Ethan Rocks")
   expect_identical(
     capture.output(summary(tmp)),
     c(""                                                                 ,
@@ -253,6 +243,91 @@ test_that("Changing the labels", {
 })
 
 
+
+test_that("A basic freqlist call", {
+  expect_identical(
+    capture.output(summary(freqlist(TAB), dupLabels = TRUE)),
+    c(""                                                               ,
+      ""                                                               ,
+      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+      "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
+      "|High  |Female |I     |    4|       4|        4.44|       4.44|",
+      "|High  |Female |II    |    8|      12|        8.89|      13.33|",
+      "|High  |Female |III   |    3|      15|        3.33|      16.67|",
+      "|High  |Male   |I     |    7|      22|        7.78|      24.44|",
+      "|High  |Male   |II    |    2|      24|        2.22|      26.67|",
+      "|High  |Male   |III   |    6|      30|        6.67|      33.33|",
+      "|Low   |Female |I     |    7|      37|        7.78|      41.11|",
+      "|Low   |Female |II    |    8|      45|        8.89|      50.00|",
+      "|Low   |Female |III   |    2|      47|        2.22|      52.22|",
+      "|Low   |Male   |I     |    5|      52|        5.56|      57.78|",
+      "|Low   |Male   |II    |    4|      56|        4.44|      62.22|",
+      "|Low   |Male   |III   |    4|      60|        4.44|      66.67|",
+      "|Med   |Female |II    |   11|      71|       12.22|      78.89|",
+      "|Med   |Female |III   |    3|      74|        3.33|      82.22|",
+      "|Med   |Male   |II    |    8|      82|        8.89|      91.11|",
+      "|Med   |Male   |III   |    8|      90|        8.89|     100.00|"
+    )
+  )
+  expect_identical(
+    capture.output(summary(freqlist(TAB, groupBy = "Group"), single = FALSE, dupLabels = TRUE)),
+    c(""                                                               ,
+      ""                                                               ,
+      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+      "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
+      "|High  |Female |I     |    4|       4|       13.33|      13.33|",
+      "|High  |Female |II    |    8|      12|       26.67|      40.00|",
+      "|High  |Female |III   |    3|      15|       10.00|      50.00|",
+      "|High  |Male   |I     |    7|      22|       23.33|      73.33|",
+      "|High  |Male   |II    |    2|      24|        6.67|      80.00|",
+      "|High  |Male   |III   |    6|      30|       20.00|     100.00|",
+      ""                                                               ,
+      ""                                                               ,
+      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+      "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
+      "|Low   |Female |I     |    7|       7|       23.33|      23.33|",
+      "|Low   |Female |II    |    8|      15|       26.67|      50.00|",
+      "|Low   |Female |III   |    2|      17|        6.67|      56.67|",
+      "|Low   |Male   |I     |    5|      22|       16.67|      73.33|",
+      "|Low   |Male   |II    |    4|      26|       13.33|      86.67|",
+      "|Low   |Male   |III   |    4|      30|       13.33|     100.00|",
+      ""                                                               ,
+      ""                                                               ,
+      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+      "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
+      "|Med   |Female |II    |   11|      11|       36.67|      36.67|",
+      "|Med   |Female |III   |    3|      14|       10.00|      46.67|",
+      "|Med   |Male   |II    |    8|      22|       26.67|      73.33|",
+      "|Med   |Male   |III   |    8|      30|       26.67|     100.00|"
+    )
+  )
+})
+
 ###########################################################################################################
 #### Reported bugs for freqlist
 ###########################################################################################################
+
+
+test_that("11/18/16: Emily Lundt's subsetted table and duplicate label problem", {
+  expect_identical(
+    capture.output(summary(freqlist(TAB.subset))),
+    c(""                                                               ,
+      ""                                                               ,
+      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+      "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
+      "|High  |Female |I     |    4|       4|        5.19|       5.19|",
+      "|      |       |II    |    8|      12|       10.39|      15.58|",
+      "|      |       |III   |    3|      15|        3.90|      19.48|",
+      "|      |Male   |I     |    7|      22|        9.09|      28.57|",
+      "|      |       |II    |    2|      24|        2.60|      31.17|",
+      "|      |       |III   |    6|      30|        7.79|      38.96|",
+      "|Low   |Female |I     |    7|      37|        9.09|      48.05|",
+      "|      |       |II    |    8|      45|       10.39|      58.44|",
+      "|      |       |III   |    2|      47|        2.60|      61.04|",
+      "|Med   |Female |II    |   11|      58|       14.29|      75.32|",
+      "|      |       |III   |    3|      61|        3.90|      79.22|",
+      "|      |Male   |II    |    8|      69|       10.39|      89.61|",
+      "|      |       |III   |    8|      77|       10.39|     100.00|"
+    )
+  )
+})
